"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from amds.types import BaseModel
from amds.utils import FieldMetadata, QueryParamMetadata
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class DeleteTunnelRequestTypedDict(TypedDict):
    tunnel_id: NotRequired[str]


class DeleteTunnelRequest(BaseModel):
    tunnel_id: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None


class DeleteTunnelResponseBodyTypedDict(TypedDict):
    r"""Delete Tunnel"""

    message: NotRequired[str]
    status: NotRequired[str]


class DeleteTunnelResponseBody(BaseModel):
    r"""Delete Tunnel"""

    message: Optional[str] = None

    status: Optional[str] = None


class DeleteTunnelResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: DeleteTunnelResponseBodyTypedDict


class DeleteTunnelResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: DeleteTunnelResponseBody
